@@ -1,8 +1,8 @@
 package Plack::Middleware::JenkinsNotification;
 use strict;
 use warnings;
-our $VERSION = '0.03';
-use parent qw/Plack::Component/;
+our $VERSION = '0.04';
+use parent qw/Plack::Middleware/;
 use Plack::Util;
 use Plack::MIME;
 use Plack::Util::Accessor qw(on_notify);
@@ -13,6 +13,7 @@ use Jenkins::NotificationListener;
 
 sub call { 
     my ($self,$env) = @_;
+
     my $req = Plack::Request->new($env);
     my $body = $req->raw_body;
 
@@ -21,10 +22,9 @@ sub call {
     if( $self->on_notify ) {
         $self->on_notify->( $env, $notification );
     }
+    $env->{ 'jenkins.notification' } = $notification;
 
-    my $response = Plack::Response->new(200);
-    $response->body('{ "success": 1 }');
-    return $response->finalize;
+    return $self->app->( $env );
 }
 
 1;
@@ -39,10 +39,19 @@ Plack::Middleware::JenkinsNotification -
     use Plack::Middleware::JenkinsNotification;
 
     builder {
+        mount "/jenkins" => builder {
+            enable "JenkinsNotification";
+            sub { 
+                my $env = shift;
+                my $notification = $env->{ 'jenkins.notification' };  # Jenkins::Notification
+
+            };
+        };
+
         mount "/jenkins" => Plack::Middleware::JenkinsNotification->new({ on_notify => sub {
             my ($env,$payload) = @_;
             
-        }});
+        }})->to_app;
     };
 
 =head1 DESCRIPTION
